@@ -1,8 +1,8 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "helix" "0.8.0"
+(define-package "helix" "20251011.1609"
   "A minor mode emulating Helix keybindings."
   '((emacs "29.1"))
   :url "https://github.com/mgmarlow/helix-mode"
-  :commit "32e01acddc582ae9eb27eabda974ce12996a9bb8"
-  :revdesc "32e01acddc58"
+  :commit "f431fe6c1def0d679f3bae987d43025f13892dba"
+  :revdesc "f431fe6c1def"
   :keywords '("convenience"))
